<?php
/**
 * Stand Alone Project Theme Functions
 *
 * @package Stand_Alone_Project
 */

if (!defined('ABSPATH')) {
    exit;
}

// Define theme version
if (!defined('STAND_ALONE_PROJECT_VERSION')) {
    define('STAND_ALONE_PROJECT_VERSION', '1.0.0');
}

// Include theme updater
require_once get_template_directory() . '/updater.php';

// Theme Setup
function mohtavanegar_setup() {
    add_theme_support('title-tag');
    add_theme_support('post-thumbnails');
    add_theme_support('elementor');
    add_theme_support('custom-logo', array(
        'height'      => 100,
        'width'       => 400,
        'flex-height' => true,
        'flex-width'  => true,
        'header-text' => array('site-title', 'site-description'),
    ));
    
    // Add WooCommerce support only if WooCommerce is active
    if (class_exists('WooCommerce')) {
        add_theme_support('woocommerce');
    }
    
    register_nav_menus(array(
        'primary' => esc_html__('Primary Menu', 'mohtavanegar'),
        'footer' => esc_html__('Footer Menu', 'mohtavanegar'),
    ));
}
add_action('after_setup_theme', 'mohtavanegar_setup');

// Enqueue scripts and styles
function mohtavanegar_scripts() {
    // Add resource hints
    add_action('wp_head', function() {
        // Preconnect to required origins
        echo '<link rel="preconnect" href="' . esc_url(site_url()) . '">';
        echo '<link rel="dns-prefetch" href="' . esc_url(site_url()) . '">';
        
        // Preload critical CSS
        echo '<link rel="preload" href="' . get_stylesheet_uri() . '" as="style">';
        
        // Add critical CSS inline
        $critical_css = file_get_contents(get_template_directory() . '/css/critical.css');
        if ($critical_css) {
            echo '<style id="mohtavanegar-critical-css">' . $critical_css . '</style>';
        }
    }, 1);

    // Dequeue unnecessary styles
    wp_dequeue_style('wp-block-library');
    wp_dequeue_style('wp-embed');
    
    // Enqueue Font Awesome for header icons
    wp_enqueue_style('font-awesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css', array(), '5.15.4');
    
   
    // Enqueue main stylesheet with media="print" and onload
    wp_enqueue_style('mohtavanegar-style', get_stylesheet_uri(), array(), '1.0');
    add_filter('style_loader_tag', function($tag, $handle) {
        if ($handle === 'mohtavanegar-style') {
            return str_replace("rel='stylesheet'", "rel='stylesheet' media='print' onload='this.media=\"all\"'", $tag);
        }
        return $tag;
    }, 10, 2);
    
    // Enqueue taxonomy services CSS for services_category taxonomy pages
    if (is_tax('services_category')) {
        wp_enqueue_style(
            'mohtavanegar-taxonomy-services', 
            get_template_directory_uri() . '/assets/css/taxonomy-services.css', 
            array(), 
            '1.0'
        );
        
        // Add Font Awesome for icons
        wp_enqueue_style(
            'font-awesome',
            'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css',
            array(),
            '5.15.4'
        );
    }

    // Enqueue scripts
    wp_enqueue_script('mohtavanegar-script', get_template_directory_uri() . '/js/main.js', array('jquery'), '1.0', true);
    
}
add_action('wp_enqueue_scripts', 'mohtavanegar_scripts');

// Include Settings Files
function mohtavanegar_load_required_files() {
    // فایل‌های اصلی
    require_once get_template_directory() . '/settings/header-settings.php';
    require_once get_template_directory() . '/settings/footer-settings.php';
    require_once get_template_directory() . '/settings/template-settings.php';
    require_once get_template_directory() . '/settings/services-post-type.php';
    require_once get_template_directory() . '/settings/taxonomy-icons.php';
    require_once get_template_directory() . '/settings/qa-post-type.php';
    require_once get_template_directory() . '/maintenance-mode.php';
    
    // افزودن تاریخ شمسی در صورت فعال بودن در تنظیمات
    $basic_settings = get_option('basic_settings', array());
    if (isset($basic_settings['jalali_date']) && $basic_settings['jalali_date'] == 1) {
        require_once get_template_directory() . '/inc/jalali-date.php';
    }
    
    // فایل‌های ادمین
    if (is_admin()) {
        require_once get_template_directory() . '/settings/theme-settings.php';
        require_once get_template_directory() . '/settings/import-export.php';
        require_once get_template_directory() . '/settings/ready-templates.php';
    }

    // فایل‌های ویجت المنتور
    if (class_exists('\Elementor\Plugin')) {
        require_once get_template_directory() . '/widgets/elementor/elementor-widgets.php';
    }
}
add_action('after_setup_theme', 'mohtavanegar_load_required_files');

// Optimize Elementor CSS loading
function mohtavanegar_optimize_elementor_css() {
    if (!class_exists('\Elementor\Plugin')) {
        return;
    }
    
    // Dequeue Elementor CSS files that are not needed
    wp_dequeue_style('elementor-frontend');
    wp_dequeue_style('elementor-global');
    
    // Enqueue only necessary Elementor CSS
    wp_enqueue_style('elementor-frontend', plugins_url('elementor/assets/css/frontend.min.css'), array(), ELEMENTOR_VERSION);
}
add_action('wp_enqueue_scripts', 'mohtavanegar_optimize_elementor_css', 20);

/**
 * Replace WordPress admin login logo with custom logo
 */
function mohtavanegar_custom_login_logo() {
    $logo_url = get_stylesheet_directory_uri() . '/assets/img/logo.webp';
    ?>
    <style type="text/css">
        body.login div#login h1 {
            display: block;
            margin-bottom: 25px;
        }
        body.login div#login h1 a {
            background-image: url('<?php echo esc_url($logo_url); ?>') !important;
            background-size: contain;
            background-position: center center;
            background-repeat: no-repeat;
            width: 320px;
            height: 120px;
            margin: 0 auto 25px;
            padding: 0;
            overflow: hidden;
            text-indent: -9999px;
            outline: 0;
            display: block;
        }
        .rtl body.login div#login h1 a {
            margin: 0 auto 25px;
        }
        .login h1 a:before {
            display: none !important;
        }
    </style>
    <?php
}
add_action('login_enqueue_scripts', 'mohtavanegar_custom_login_logo');

// Update login logo URL to site URL
function mohtavanegar_login_logo_url() {
    return home_url();
}
add_filter('login_headerurl', 'mohtavanegar_login_logo_url');

// Update login logo title to site name
function mohtavanegar_login_logo_url_title() {
    return get_bloginfo('name');
}
add_filter('login_headertext', 'mohtavanegar_login_logo_url_title');

/**
 * Ensure timestamps are properly converted to integers
 * Fix for 'gmdate(): Argument #2 ($timestamp) must be of type ?int, string given' error
 */
add_filter('get_the_time', function($the_time, $d, $post) {
    if ($d === 'U') {
        return (int) $the_time; // Ensure Unix timestamp is returned as integer
    }
    return $the_time;
}, 10, 3);

